﻿/*
**  ListPrinters.c
**
** 2021.9.2
**
 * Copyright:       Copyright (C) 2021 PDF Tools AG, Switzerland
 *                  Permission to use, copy, modify, and distribute this
 *                  software and its documentation for any purpose and without
 *                  fee is hereby granted, provided that the above copyright
 *                  notice appear in all copies and that both that copyright
 *                  notice and this permission notice appear in supporting
 *                  documentation. This software is provided "as is" without
 *                  express or implied warranty.
**
** Copyright (C) 2021 株式会社トラスト・ソフトウェア・システム
*/

#include <stdio.h>
#include <windows.h>
#include <locale.h>
#include "Printer_c.h"

#pragma comment(lib,"PdfPrintAPI.lib")

int main()
{
    int iReturnValue = 0;

    setlocale(LC_CTYPE, "Japanese");

    // ライブラリの初期化
    PDFPrnInitialize();

    // ライセンスキー
    // 重要：以下の関数を利用するのは評価ライセンスまたはOEMライセンスの場合だけです。
    //  それ以外のライセンでは「License Manager」を使ってライセンスを有効化してください。
    if (!PDFPrnSetLicenseKey(_T("1-5QA2Q-XSM79-BCDDC-5AJ1K-741E1-BWM0V-Q9VV7")))
    {
        _tprintf(_T("不正なライセンスキー\n"));
        return 1;
    }

    //出力ファイル
    TCHAR* szTextFilePath = NULL; //_T("output.txt");

    // インスタンス生成
    TPdfPrinter* pPrinter = PDFPrnCreateObject();

    // 有効なローカルプリンターのリストを出力するファイル生成
    FILE* pTxtFile;
    if (szTextFilePath && *szTextFilePath)
        _tfopen_s(&pTxtFile, szTextFilePath, _T("w"));
    else
        pTxtFile = stdout;
    _ftprintf(pTxtFile, _T("List of available printers in localhost:\n"));
    _ftprintf(pTxtFile, _T("----------------------------------------\n"));

    // 全ローカルプリンター
    for (int iPrinter = 0, nPrinters = PDFPrnGetPrinterCount(pPrinter, _T("")); iPrinter < nPrinters; iPrinter++)
    {
        TCHAR szPrinterName[256];
       _tcscpy_s(szPrinterName, 256, PDFPrnGetPrinter(pPrinter, iPrinter));
       _ftprintf(pTxtFile, _T("プリンター %d: %s\n"), iPrinter + 1, szPrinterName);

       // プリンターを開く
       if (!PDFPrnOpenPrinter(pPrinter, szPrinterName))
       {
           _tprintf(_T("プリンター %s を開けません。\n%s (エラー: 0x%08x).\n"), szPrinterName, PDFPrnGetErrorMessage(pPrinter), PDFPrnGetErrorCode(pPrinter));
           continue;
       }

        // プリンターの Duplex modes リスト
        _ftprintf(pTxtFile, _T("  Duplex Modes:\n"));
        for (int j = 0, n = PDFPrnGetDuplexModeCount(pPrinter, szPrinterName); j < n; j++)
            _ftprintf(pTxtFile, _T("   - %s\n"), PDFPrnGetDuplexMode(pPrinter, j));

        // プリンターのトレーリスト
        _ftprintf(pTxtFile, _T("  トレー:\n"));
        for (int j = 0, n = PDFPrnGetBinCount(pPrinter, szPrinterName); j < n; j++)
            _ftprintf(pTxtFile, _T("   - %s\n"), PDFPrnGetBin(pPrinter, j));

        // プリンターの用紙リスト
        _ftprintf(pTxtFile, _T("  用紙:\n"));
        for (int j = 0, n = PDFPrnGetPaperCount(pPrinter, szPrinterName); j < n; j++)
            _ftprintf(pTxtFile, _T("   - %s\n"), PDFPrnGetPaper(pPrinter, j));

        // プリンターのMedia typesリスト
        _ftprintf(pTxtFile, _T("  Media Types:\n"));
        for (int j = 0, n = PDFPrnGetMediaTypeCount(pPrinter, szPrinterName); j < n; j++)
            _ftprintf(pTxtFile, _T("   - %s\n"), PDFPrnGetMediaTypeName(pPrinter, j));

        // プリンターを閉じる
        PDFPrnClosePrinter(pPrinter);

        _ftprintf(pTxtFile, _T("----------------------------------------\n"));
    }

    _tprintf(_T("終了\n"));

    PDFPrnDestroyObject(pPrinter);
    PDFPrnUnInitialize();

    return iReturnValue;
}
