﻿/*
**  MultiJobOnePrinter.c
**
**  2021.8.31
*/

#include <stdio.h>
#include <windows.h>
#include <locale.h>
#include "Printer_c.h"

#pragma comment(lib,"PdfPrintAPI.lib")

int printDocument(TPdfPrinter* pPrinter, TCHAR* szInputPath, TCHAR* szPrinterName);
int iReturnValue = 0;

int main()
{
    setlocale(LC_CTYPE, "Japanese");

    // Initialize library
    PDFPrnInitialize();

    // ライセンスキー
    // 重要：以下の関数を利用するのは評価ライセンスまたはOEMライセンスの場合だけです。
    //  それ以外のライセンでは「License Manager」を使ってライセンスを有効化してください。
    if (!PDFPrnSetLicenseKey(_T("1-18A0G-XTH79-RCD4C-5E21H-F40A1-BCM1A-Q9REM")))
    {
        _tprintf(_T("不正なライセンスキー\n"));
        return 1;
    }

    // プリンターと入力ファイル
    TCHAR* szPrinterName = _T("Microsoft XPS Document Writer");
    TCHAR* szFirstInputPath = _T("../../FormNone.pdf");
    TCHAR* szSecondInputPath = _T("../../GraphicsNone.pdf");

    // インスタンス生成
    TPdfPrinter* pPrinter = PDFPrnCreateObject();

    // プリンターを開く
    if (!PDFPrnOpenPrinter(pPrinter, szPrinterName))
    {
        _tprintf(_T("プリンター \"%s\" を開けません。\n%s (エラー: 0x%08x).\n"), szPrinterName, PDFPrnGetErrorMessage(pPrinter), PDFPrnGetErrorCode(pPrinter));
        iReturnValue = 1;
        goto cleanup;
    }

    // リンクされた印刷ジョブのチェーンを開始
    if (!PDFPrnBeginGroup(pPrinter))
    {
        _tprintf(_T("印刷ジョブのチェーンを開始できません。\n%s (エラー: 0x%08x).\n"), PDFPrnGetErrorMessage(pPrinter), PDFPrnGetErrorCode(pPrinter));
        iReturnValue = 1;
        goto cleanup;
    }

    // 最初のジョブ
    if(printDocument(pPrinter, szFirstInputPath, szPrinterName)) goto cleanup;

    // 次のジョブ
    if(printDocument(pPrinter, szSecondInputPath, szPrinterName)) goto cleanup;

    // リンクされた印刷ジョブのチェーンの終了
    if (!PDFPrnEndGroup(pPrinter))
    {
        _tprintf(_T("印刷ジョブのチェーンを正しく終了できません。\n%s (エラー: 0x%08x).\n"), PDFPrnGetErrorMessage(pPrinter), PDFPrnGetErrorCode(pPrinter));
        iReturnValue = 1;
        goto cleanup;
    }

    _tprintf(_T("終了\n"));

    // 後始末
cleanup:
    PDFPrnClosePrinter(pPrinter);
    PDFPrnDestroyObject(pPrinter);
    PDFPrnUnInitialize();

    return iReturnValue;
}

int printDocument(TPdfPrinter* pPrinter, TCHAR* szInputPath, TCHAR* szPrinterName)
{
    // 印刷ジョブ開始
    if (!PDFPrnBeginDocument(pPrinter, _T("My print job.")))
    {
        _tprintf(_T("プリンタへ接続できません。\n%s (エラー: 0x%08x).\n"), PDFPrnGetErrorMessage(pPrinter), PDFPrnGetErrorCode(pPrinter));
        iReturnValue = 1;
        goto cleanup;
    }

    // 入力ファイルを開く
    if (!PDFPrnOpen(pPrinter, szInputPath, _T("")))
    {
        _tprintf(_T("入力ファイル %s を開けません。\n%s (エラー: 0x%08x).\n"), szInputPath, PDFPrnGetErrorMessage(pPrinter), PDFPrnGetErrorCode(pPrinter));
        iReturnValue = 1;
        goto cleanup;
    }

    // 入力ファイルの全ページ
    for (int iPage = 1; iPage <= PDFPrnGetPageCount(pPrinter); iPage++)
    {
        // ファイル内のページを印刷
        if (!PDFPrnPrintPage(pPrinter, iPage))
        {
            _tprintf(_T("ファイル(%s) ページ-%d をプリンター\"%s\"で印刷できません。\n%s (エラー: 0x%08x).\n"), szInputPath, iPage, szPrinterName, PDFPrnGetErrorMessage(pPrinter), PDFPrnGetErrorCode(pPrinter));
            iReturnValue = 1;
            goto cleanup;
        }
    }

    // 入力ファイルを閉じる
    PDFPrnClose(pPrinter);

    if (!PDFPrnEndDocument(pPrinter))
    {
        _tprintf(_T("印刷ジョブは不正に終了しました。\n%s (エラー: 0x%08x).\n"), PDFPrnGetErrorMessage(pPrinter), PDFPrnGetErrorCode(pPrinter));
        iReturnValue = 1;
    }

cleanup:
    PDFPrnEndDocument(pPrinter);

    return iReturnValue;
}
