﻿// OneDocMultiPrinter.c
//
/*
**  OneDocMultiPrinter.c
**
** 2021.9.1
*/

#include <stdio.h>
#include <windows.h>
#include <locale.h>
#include "Printer_c.h"

#pragma comment(lib,"PdfPrintAPI.lib")


#include <stdio.h>

int main()
{
    int iReturnValue = 0;

    setlocale(LC_CTYPE, "Japanese");

    // Initialize library
    PDFPrnInitialize();

    // ライセンスキー
    // 重要：以下の関数を利用するのは評価ライセンスまたはOEMライセンスの場合だけです。
    //  それ以外のライセンでは「License Manager」を使ってライセンスを有効化してください。
    if (!PDFPrnSetLicenseKey(_T("1-18A0G-XTH79-RCD4C-5E21H-F40A1-BCM1A-Q9REM")))
    {
        _tprintf(_T("不正なライセンスキー\n"));
        return 1;
    }

    // プリンターと入力ファイル
    TCHAR* szInputPath = _T("../../GraphicsNone.pdf");
    TCHAR* szFirstPrinterName = _T("Microsoft XPS Document Writer");
    TCHAR* szSecondPrinterName = _T("Adobe PDF");
    int iPageNumber = 1;

    // インスタンス生成
    TPdfPrinter* pPrinter = PDFPrnCreateObject();

    // 入力ファイルを開く
    if (!PDFPrnOpen(pPrinter, szInputPath, _T("")))
    {
        _tprintf(_T("入力ファイル %s をオープンできません。\n%s (エラー: 0x%08x).\n"), szInputPath, PDFPrnGetErrorMessage(pPrinter), PDFPrnGetErrorCode(pPrinter));
        iReturnValue = 1;
    }

    // 最初のプリンターを開く
    if (!PDFPrnOpenPrinter(pPrinter, szFirstPrinterName))
    {
        _tprintf(_T("プリンター %s をオープンできません。\n%s (エラー: 0x%08x).\n"), szFirstPrinterName, PDFPrnGetErrorMessage(pPrinter), PDFPrnGetErrorCode(pPrinter));
        iReturnValue = 1;
        goto cleanup;
    }

    // 最初のプリンタージョブを開始
    if (!PDFPrnBeginDocument(pPrinter, _T("My first print job.\n")))
    {
        _tprintf(_T("プリンターに接続できません。\n%s (エラー: 0x%08x).\n"), PDFPrnGetErrorMessage(pPrinter), PDFPrnGetErrorCode(pPrinter));
        iReturnValue = 1;
        goto cleanup;
    }

    // 入力ファイルの指定ページを印刷
    if (!PDFPrnPrintPage(pPrinter, iPageNumber))
    {
        _tprintf(_T("ファイル %s の %d ページを %s に印刷できません。\n%s (エラー: 0x%08x).\n"), szInputPath, iPageNumber, szFirstPrinterName, PDFPrnGetErrorMessage(pPrinter), PDFPrnGetErrorCode(pPrinter));
        iReturnValue = 1;
        goto cleanup;
    }

    // 最初のプリンタージョブを終了
    if (!PDFPrnEndDocument(pPrinter))
    {
        _tprintf(_T("プリンター %s への印刷を失敗\n%s (エラー: 0x%08x).\n"), szFirstPrinterName, PDFPrnGetErrorMessage(pPrinter), PDFPrnGetErrorCode(pPrinter));
        iReturnValue = 1;
        goto cleanup;
    }

    // 最初のプリンターを閉じる
    PDFPrnClosePrinter(pPrinter);

    // ２番目のプリンターを開く
    if (!PDFPrnOpenPrinter(pPrinter, szSecondPrinterName))
    {
        _tprintf(_T("プリンター %s をオープンできません。\n%s (エラー: 0x%08x).\n"), szSecondPrinterName, PDFPrnGetErrorMessage(pPrinter), PDFPrnGetErrorCode(pPrinter));
        iReturnValue = 1;
        goto cleanup;
    }

    // ２番目のプリンタージョブを開始
    if (!PDFPrnBeginDocument(pPrinter, _T("My second print job.\n")))
    {
        _tprintf(_T("プリンターに接続できません。\n%s (エラー: 0x%08x).\n"), PDFPrnGetErrorMessage(pPrinter), PDFPrnGetErrorCode(pPrinter));
        iReturnValue = 1;
        goto cleanup;
    }

    // ２頁目から最後のページまでを印刷
    for (int iPage = 2; iPage < PDFPrnGetPageCount(pPrinter); iPage++)
    {
        // 入力ファイルの各ページを印刷
        if (!PDFPrnPrintPage(pPrinter, iPage))
        {
            _tprintf(_T("プリンター %s のページ %d を印刷できません。\n%s (エラー: 0x%08x).\n"), szSecondPrinterName, iPage, PDFPrnGetErrorMessage(pPrinter), PDFPrnGetErrorCode(pPrinter));
            iReturnValue = 1;
            goto cleanup;
        }
    }

    // ２番目のプリンターを閉じる
    PDFPrnClosePrinter(pPrinter);

    // 入力ファイルを閉じる
    PDFPrnClose(pPrinter);

    _tprintf(_T("終了\n"));

cleanup:
    PDFPrnClosePrinter(pPrinter);
    PDFPrnDestroyObject(pPrinter);
    PDFPrnUnInitialize();

    return iReturnValue;
}
