﻿/*
**  SingleDocOnePrinter.c
**
** 2028.8.31
*/

#include <stdio.h>
#include <windows.h>
#include <locale.h>
#include "Printer_c.h"

#pragma comment(lib,"PdfPrintAPI.lib")

int main()
{
    int iReturnValue = 0;

    setlocale(LC_CTYPE, "Japanese");

    // Initialize library
    PDFPrnInitialize();

    // ライセンスキー
    // 重要：以下の関数を利用するのは評価ライセンスまたはOEMライセンスの場合だけです。
    //  それ以外のライセンでは「License Manager」を使ってライセンスを有効化してください。
    if (!PDFPrnSetLicenseKey(_T("1-18A0G-XTH79-RCD4C-5E21H-F40A1-BCM1A-Q9REM")))
    {
        _tprintf(_T("Wrong license key set.\n"));
        return 1;
    }

    TCHAR* szPrinterName = _T("Microsoft XPS Document Writer");
    //TCHAR* szPrinterName = _T("Adobe PDF");
    TCHAR* szInputPath = _T("../../GraphicsNone.pdf");

    // インスタンス生成
    TPdfPrinter* pPrinter = PDFPrnCreateObject();

    // 指定のプリンターを開く
    if (!PDFPrnOpenPrinter(pPrinter, szPrinterName))
    {
        _tprintf(_T("プリンター %s を開けません。\n%s (エラー: 0x%08x).\n"), szPrinterName, PDFPrnGetErrorMessage(pPrinter), PDFPrnGetErrorCode(pPrinter));
        iReturnValue = 1;
        goto cleanup;
    }

    // 印刷ジョブを開始
    if (!PDFPrnBeginDocument(pPrinter, _T("My print job.")))
    {
        _tprintf(_T("プリンターに接続できません。\n%s (エラー: 0x%08x).\n"), PDFPrnGetErrorMessage(pPrinter), PDFPrnGetErrorCode(pPrinter));
        iReturnValue = 1;
        goto cleanup;
    }

    // 入力ファイルをオープン
    if (!PDFPrnOpen(pPrinter, szInputPath, _T("")))
    {
        _tprintf(_T("入力ファイル %s をオープンできません。\n%s (エラー: 0x%08x).\n"), szInputPath, PDFPrnGetErrorMessage(pPrinter), PDFPrnGetErrorCode(pPrinter));
        iReturnValue = 1;
        goto cleanup;
    }

    // 入力ファイルの全ページを印刷
    for (int iPage = 1; iPage <= PDFPrnGetPageCount(pPrinter); iPage++)
    {
        // Print pages of input file
        if (!PDFPrnPrintPage(pPrinter, iPage))
        {
            _tprintf(_T("入力ファイル %s のページ %d を印刷できません。\n%s (エラー: 0x%08x).\n"), szPrinterName, iPage, PDFPrnGetErrorMessage(pPrinter), PDFPrnGetErrorCode(pPrinter));
            iReturnValue = 1;
            goto cleanup;
        }
    }

    // 入力ファイルを閉じる
    PDFPrnClose(pPrinter);

    // 印刷ジョブを終了
    if (!PDFPrnEndDocument(pPrinter))
    {
        _tprintf(_T("印刷ジョブを終了失敗\n%s (エラー: 0x%08x)."), PDFPrnGetErrorMessage(pPrinter), PDFPrnGetErrorCode(pPrinter));
        iReturnValue = 1;
        goto cleanup;
    }

    _tprintf(_T("終了\n"));

    // 後始末
cleanup:
    PDFPrnClosePrinter(pPrinter);
    PDFPrnDestroyObject(pPrinter);
    PDFPrnUnInitialize();

    return iReturnValue;
}
