﻿/*
**  ToFile.c
**
** 2021.9.2
**
 * Copyright:       Copyright (C) 2021 PDF Tools AG, Switzerland
 *                  Permission to use, copy, modify, and distribute this
 *                  software and its documentation for any purpose and without
 *                  fee is hereby granted, provided that the above copyright
 *                  notice appear in all copies and that both that copyright
 *                  notice and this permission notice appear in supporting
 *                  documentation. This software is provided "as is" without
 *                  express or implied warranty.
**
** Copyright (C) 2021 株式会社トラスト・ソフトウェア・システム
*/

#include <stdio.h>
#include <windows.h>
#include <locale.h>
#include "Printer_c.h"

#pragma comment(lib,"PdfPrintAPI.lib")

int main()
{
    int iReturnValue = 0;

    setlocale(LC_CTYPE, "Japanese");

    // ライブラリの初期化
    PDFPrnInitialize();

    // ライセンスキー
    // 重要：以下の関数を利用するのは評価ライセンスまたはOEMライセンスの場合だけです。
    //  それ以外のライセンでは「License Manager」を使ってライセンスを有効化してください。
    if (!PDFPrnSetLicenseKey(_T("1-5QA2Q-XSM79-BCDDC-5AJ1K-741E1-BWM0V-Q9VV7")))
    {
        _tprintf(_T("不正なライセンスキー\n"));
        return 1;
    }

    TCHAR* szInputPath = _T("../../GraphicsNone.pdf");
    TCHAR* szPrinterName = _T("Microsoft XPS Document Writer");
    TCHAR* szOutputPath = _T("output.pcl");

    // インスタンス生成
    TPdfPrinter* pPrinter = PDFPrnCreateObject();

    // 指定のプリンターを開く
    if (!PDFPrnOpenPrinter(pPrinter, szPrinterName))
    {
        _tprintf(_T("プリンター %s を開けません。\n%s (エラー: 0x%08x).\n"), szPrinterName, PDFPrnGetErrorMessage(pPrinter), PDFPrnGetErrorCode(pPrinter));
        iReturnValue = 1;
        goto cleanup;
    }

    // 出力ファイルを指定
    PDFPrnSetOutput(pPrinter, szOutputPath);

    // 印刷ジョブを開始
    if (!PDFPrnBeginDocument(pPrinter, _T("My print job.")))
    {
        _tprintf(_T("プリンターに接続できません。\n%s (エラー: 0x%08x).\n"), PDFPrnGetErrorMessage(pPrinter), PDFPrnGetErrorCode(pPrinter));
        iReturnValue = 1;
        goto cleanup;
    }

    // 入力ファイルをオープン
    if (!PDFPrnOpen(pPrinter, szInputPath, _T("")))
    {
        _tprintf(_T("入力ファイル %s をオープンできません。\n%s (エラー: 0x%08x).\n"), szInputPath, PDFPrnGetErrorMessage(pPrinter), PDFPrnGetErrorCode(pPrinter));
        iReturnValue = 1;
        goto cleanup;
    }

    // 入力ファイルの全ページを印刷
    for (int iPage = 1; iPage <= PDFPrnGetPageCount(pPrinter); iPage++)
    {
        // Print pages of input file
        if (!PDFPrnPrintPage(pPrinter, iPage))
        {
            _tprintf(_T("入力ファイル %s のページ %d を印刷できません。\n%s (エラー: 0x%08x).\n"), szPrinterName, iPage, PDFPrnGetErrorMessage(pPrinter), PDFPrnGetErrorCode(pPrinter));
            iReturnValue = 1;
            goto cleanup;
        }
    }

    // 入力ファイルを閉じる
    PDFPrnClose(pPrinter);

    // 印刷ジョブを終了
    if (!PDFPrnEndDocument(pPrinter))
    {
        _tprintf(_T("印刷ジョブを終了失敗\n%s (エラー: 0x%08x)."), PDFPrnGetErrorMessage(pPrinter), PDFPrnGetErrorCode(pPrinter));
        iReturnValue = 1;
        goto cleanup;
    }

    _tprintf(_T("終了\n"));

cleanup:
    PDFPrnClosePrinter(pPrinter);
    PDFPrnDestroyObject(pPrinter);
    PDFPrnUnInitialize();

    return iReturnValue;
}
