﻿/*
**	Watermarks.c
**
** 2021.9.2
**
 * Copyright:       Copyright (C) 2021 PDF Tools AG, Switzerland
 *                  Permission to use, copy, modify, and distribute this
 *                  software and its documentation for any purpose and without
 *                  fee is hereby granted, provided that the above copyright
 *                  notice appear in all copies and that both that copyright
 *                  notice and this permission notice appear in supporting
 *                  documentation. This software is provided "as is" without
 *                  express or implied warranty.
**
** Copyright (C) 2021 株式会社トラスト・ソフトウェア・システム
*/

#include <stdio.h>
#include <windows.h>
#include <math.h>
#include <locale.h>
#include "Printer_c.h"

#pragma comment(lib,"PdfPrintAPI.lib")

int main()
{
    int iReturnValue = 0;

    setlocale(LC_CTYPE, "Japanese");

    // ライブラリを初期化
    PDFPrnInitialize();

    // ライセンスキー
    // 重要：以下の関数を利用するのは評価ライセンスまたはOEMライセンスの場合だけです。
    //  それ以外のライセンでは「License Manager」を使ってライセンスを有効化してください。
    if (!PDFPrnSetLicenseKey(_T("1-5QA2Q-XSM79-BCDDC-5AJ1K-741E1-BWM0V-Q9VV7")))
    {
        _tprintf(_T("不正なライセンスキー\n"));
        return 1;
    }

    //TCHAR* szInputPath = _T("../../GraphicsNone.pdf");
    TCHAR* szInputPath = _T("https://www.pdf-tools.trustss.co.jp/data/Receipt2.pdf");
    TCHAR* szWatermarkText = _T("承認済み");

    // インスタンス生成
    TPdfPrinter* pPrinter = PDFPrnCreateObject();

    // 入力ファイルを開く
    if (!PDFPrnOpen(pPrinter, szInputPath, _T("")))
    {
        _tprintf(_T("入力ファイル %s を開けません。\n%s (エラー: 0x%08x).\n"), szInputPath, PDFPrnGetErrorMessage(pPrinter), PDFPrnGetErrorCode(pPrinter));
        iReturnValue = 1;
        goto cleanup;
    }

    // 既定のプリンターを検索
    const TCHAR* szPrinterName = PDFPrnGetDefaultPrinter(pPrinter);
    if (szPrinterName == NULL || (_tcscmp(szPrinterName, _T("")) == 0))
    {
        _tprintf(_T("既定のプリンターがありません。\n"));
        iReturnValue = 1;
        goto cleanup;
    }

    // プリンターを開く
    if (!PDFPrnOpenPrinter(pPrinter, szPrinterName))
    {
        _tprintf(_T("プリンター %s を開けません。\n%s (エラー: 0x%08x).\n"), szPrinterName, PDFPrnGetErrorMessage(pPrinter), PDFPrnGetErrorCode(pPrinter));
        iReturnValue = 1;
        goto cleanup;
    }

    // 印刷ジョブ開始
    if (!PDFPrnBeginDocument(pPrinter, _T("Watermark print job.")))
    {
        _tprintf(_T("プリンターに接続できません。\n%s (エラー: 0x%08x).\n"), PDFPrnGetErrorMessage(pPrinter), PDFPrnGetErrorCode(pPrinter));
        iReturnValue = 1;
        goto cleanup;
    }

    PDFPrnSetCenter(pPrinter, 1);
    PDFPrnSetPaperSize(pPrinter, -2);

    // 入力ファイルの各ページを印刷
    float fWidth;
    float fHeight;
    float fFontSize;
    for (int iPage = 1; iPage <= PDFPrnGetPageCount(pPrinter); iPage++)
    {
        // 透かしを奇数ページに追加
        if (iPage % 2 == 1)
        {
            PDFPrnSetPageNo(pPrinter, iPage);
            fWidth = PDFPrnGetPageWidth(pPrinter);
            fHeight = PDFPrnGetPageHeight(pPrinter);
            fFontSize = (float)sqrt(fWidth * fWidth + fHeight * fHeight) / _tcslen(szWatermarkText);

            PDFPrnSetWatermarkBold(pPrinter, 1);
            PDFPrnSetWatermarkOutline(pPrinter, 1);
            PDFPrnSetWatermarkFontName(pPrinter, _T("ＭＳ 明朝"));
            PDFPrnSetWatermarkFontSize(pPrinter, fFontSize);
            PDFPrnSetWatermarkColor(pPrinter, 0xCCCCCC);
            PDFPrnSetWatermarkXPos(pPrinter, fWidth / 5);
            PDFPrnSetWatermarkYPos(pPrinter, (fHeight - fHeight / 5 + fFontSize / 2));
            PDFPrnSetWatermarkAngle(pPrinter, (float)atan((double)fHeight / fWidth));
            PDFPrnAddWatermarkText(pPrinter, szWatermarkText);
        }
        else
        {
            // 透かしを削除
            PDFPrnDeleteWatermarks(pPrinter);
        }

        // ページを印刷
        if (!PDFPrnPrintPage(pPrinter, iPage))
        {
            _tprintf(_T("ファイル %s のページ %d をプリンター %s に印刷できません。\n%s (ErrorCode: 0x%08x).\n"), szInputPath, iPage, szPrinterName, PDFPrnGetErrorMessage(pPrinter), PDFPrnGetErrorCode(pPrinter));
            iReturnValue = 1;
            goto cleanup;
        }
    }

    // 入力ファイルを閉じる
    PDFPrnClose(pPrinter);

    // 印刷ジョブを終了
    if (!PDFPrnEndDocument(pPrinter))
    {
        _tprintf(_T("印刷ジョブを終了失敗\n%s (エラー: 0x%08x)."), PDFPrnGetErrorMessage(pPrinter), PDFPrnGetErrorCode(pPrinter));
        iReturnValue = 1;
        goto cleanup;
    }

    _tprintf(_T("終了\n"));

cleanup:
    PDFPrnClosePrinter(pPrinter);
    PDFPrnDestroyObject(pPrinter);
    PDFPrnUnInitialize();

    return iReturnValue;
}
